Actualizaciones y Reversiones

La última imagen creada está disponible aquí.

Siguiente versión de la última imagen

Exhibe el estado del despliegue actualmente en ejecución:

$ rpm-ostree status

El rpm-ostree la orden suele dirigir el árbol de sistema atómico utilizado por la Fedora IoT imágenes. La orden de actualización es un alias para el upgrade orden.

Vista las opciones con:

$ rpm-ostree upgrade --help
Modo de empleo:
  rpm-ostree upgrade [OPCIÓN…]

Realiza una mejora del sistema

Opciones de ayuda:
  -h, --help                                         Muestra opciones de ayuda

Opciones de aplicación:
  --os=OSNAME                               Opera sobre OSNAME proporcionado
  -r, --reboot                                      Iniciar un reinicie tras la operación sea completada
  --allow-downgrade                    Permite desplegar árboles más antiguos cronológicamente
  --preview                                        Tan solo vista previa de diferencias de paquete
  --check                                             Tan solo controla si está disponible una mejora
  -C, --cache-only                             No descarga el ostree último y los datos de RPM
  --download-only                             Descarga únicamente, el último ostree y datos de RPM, no despliega
  --upgrade-unchanged-exit-77     Si no es posible mejorar, salida 77
  --sysroot=SYSROOT                     Raíz del uso del sistema SYSROOT (predet.: /)
  --peer                                                 Fuerza una conexión peer-to-peer en vez de utilizar el bus de mensaje del sistema
  --install=PKG                                  Sobrecarga del paquete adicional
  --uninstall=PKG                            Retira paquetes adicionales subrecargados
  --version                                          Declara la información de la versión y sale

Compruebe si hay actualizaciones disponibles:

$ sudo rpm-ostree upgrade --check
Receiving metadata objects: 0/(estimating) -/s 0 bytes... done
AvailableUpdate:
        Version: 29.20190211.0 (2019-02-11T13:18:27Z)
         Commit: 5eb0553c02a8035a02f030c7fb8d5c6727d1ecb2700dade4b767363acfcab8e4
   GPGSignature: Valid signature by C2A3FA9DC67F68B98BB543F47BB90722DBBDCF7C
           Diff: 25 upgraded

Vista previa de las diferencias del paquete:

$ sudo rpm-ostree upgrade --preview

Si lo desea, puede descargar únicamente los paquetes y no desplegarlos con:

$ sudo rpm-ostree upgrade --download-only

Para aplicar la actualización de delta del OSTree disponible en CDN, utilice el siguiente comando:

$ sudo rpm-ostree upgrade

Debido a la naturaleza atómica del sistema operativo, tendrá que reiniciar el equipo con la nueva imagen para que las actualizaciones surtan efecto:

$ sudo systemctl reboot

Revertir a un árbol anterior

La utilidad rpm-ostree mantiene dos despliegues disponibles. Ambos tienen un apunte en el menú del gestor de arranque. El apunte actualizado será la predeterminada. Si es necesario, puede seleccionar el otro apuntes para arrancar internamente con el despliegue anterior.

El tiempo de espera para que GRUB2 exhiba el menú es muy corto, de tan solo un segundo. Si pulsas la barra espaciadora o una tecla de flecha cuando aparezca el menú, se interrumpirá la espera y podrás elegir otra opción. La tecla ENTRAR iniciará la imagen seleccionada.

Para volver permanentemente a la configuración anterior:

$ sudo rpm-ostree rollback

Al igual que con la mejora, será necesario reiniciar el sistema. Puede usar el comando systemctl reboot o incluir la opción --reboot al emite el comando de reversión:

$ sudo rpm-ostree rollback --reboot
Puede encontrar más información sobre Arranque con GRUB2 en la documentación rápida de Fedora.
Encontrará más información sobre el comando rpm-ostree en el repositorio principal Manual del administrador

Actualizaciones automáticas

El servicio rpm-ostreed está disponible para supervisar automáticamente las mejoras.

Para habilitar las actualizaciones automáticas, edite el archivo /etc/rpm-ostreed.conf. Las opciones disponibles son las siguientes:

  • La opción 'ninguna' inhabilita las actualizaciones automáticas. Esta es la normativa predeterminada.

  • La opción 'check' descarga suficientes metadatos para exhibir las actualizaciones disponibles con rpm-ostree status.

  • La opción 'stage' descarga, descomprime y prepara la actualización, que se finalizará al reiniciar el sistema.

  • La opción "Aplicar" es igual que la de "Preparar", pero además inicia el reinicio a la versión nueva.

# cat /etc/rpm-ostreed.conf
# Los apuntes de este archivo muestran los valores predeterminados en tiempo de compilación.
# Puedes cambiar la configuración editando este archivo.
# Para conocer el significado de las opciones, consulte rpm-ostreed.conf(5).

[Daemon]
AutomaticUpdatePolicy=check
#IdleExitTimeout=60

A continuación, debemos habilitar los servicios correspondientes:

systemctl reload rpm-ostreed
systemctl enable rpm-ostreed-automatic.timer --now

Ahora deberíamos seríamos capaces de ver el estado de las actualizaciones automáticas en el estado:

# rpm-ostree status
State: idle
AutomaticUpdates: stage; rpm-ostreed-automatic.timer: last run 4min 22s ago

Los servicios rpm-ostreed-automatic.service y rpm-ostreed-automatic.timer controlan la frecuencia de las comprobaciones y actualizaciones. Para obtener más información, consulte las páginas del manual o este enlace: https://miabbott.github.io/2018/06/13/rpm-ostree-automatic-updates.html [publicación del blog]